@@ -5,7 +5,7 @@ as.GNARnet <- function(x){
     if(is.matrix(x)){
       return(matrixtoGNAR(x))
     }else{
-      results <- vector(mode="logical", length=5)
+      results <- vector(mode="logical", length=8)
       results[1] <- is.list(x)
       results[2] <- sum(names(x) == c("edges", "dist"))==2
       results[3] <- length(x$edges)==length(x$dist)
@@ -13,6 +13,12 @@ as.GNARnet <- function(x){
         results[4] <- all(sapply(x$edges, length)==sapply(x$dist,length))
         tmp2 <- 1:length(x$edges)
         results[5] <- all(unlist(x$edges)%in%tmp2)
+        results[6] <- all(sapply(x$edges, length)==sapply(lapply(x$edges, unique), length))
+        results[7] <- all(unlist(x$dist)>0)
+        selfloop <- function(n){
+          return(n %in% x$edges[[n]])
+        }
+        results[8] <- all(sapply(tmp2, selfloop)==FALSE)
         if(all(results)){
           class(x) <- "GNARnet"
           return(x)
